==> myfaces-tobago-5.14.0-dist.zip: org/apache/myfaces/tobago/internal/renderkit/renderer/FormRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.renderkit.renderer;

import org.apache.myfaces.tobago.internal.component.AbstractUIForm;
import org.apache.myfaces.tobago.renderkit.RendererBase;
import org.apache.myfaces.tobago.renderkit.css.BootstrapClass;
import org.apache.myfaces.tobago.renderkit.html.HtmlElements;
import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;

import javax.faces.context.FacesContext;
import java.io.IOException;

public class FormRenderer<T extends AbstractUIForm> extends RendererBase<T> {

  @Override
  public void encodeBeginInternal(final FacesContext facesContext, final T component) throws IOException {
    if (!component.isPlain()) {
      final TobagoResponseWriter writer = getResponseWriter(facesContext);
      final String clientId = component.getClientId(facesContext);
      final boolean inline = component.isInline();

      writer.startElement(HtmlElements.TOBAGO_FORM);
      writer.writeIdAttribute(clientId);
      writer.writeClassAttribute(
          inline ? BootstrapClass.D_INLINE : null,
          component.getCustomClass());
    }
  }

  @Override
  public void encodeEndInternal(final FacesContext facesContext, final T component) throws IOException {

    if (!component.isPlain()) {
      final TobagoResponseWriter writer = getResponseWriter(facesContext);
      writer.endElement(HtmlElements.TOBAGO_FORM);
    }
  }
}

==> myfaces-tobago-6.7.2-dist.zip: org/apache/myfaces/tobago/internal/renderkit/renderer/FormRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.renderkit.renderer;

import org.apache.myfaces.tobago.internal.component.AbstractUIForm;
import org.apache.myfaces.tobago.renderkit.RendererBase;
import org.apache.myfaces.tobago.renderkit.css.BootstrapClass;
import org.apache.myfaces.tobago.renderkit.html.HtmlElements;
import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;

import jakarta.faces.context.FacesContext;

import java.io.IOException;

public class FormRenderer<T extends AbstractUIForm> extends RendererBase<T> {

  @Override
  public void encodeBeginInternal(final FacesContext facesContext, final T component) throws IOException {
    if (!component.isPlain()) {
      final TobagoResponseWriter writer = getResponseWriter(facesContext);
      final String clientId = component.getClientId(facesContext);
      final boolean inline = component.isInline();

      writer.startElement(HtmlElements.TOBAGO_FORM);
      writer.writeIdAttribute(clientId);
      writer.writeClassAttribute(
          inline ? BootstrapClass.D_INLINE : null,
          component.getCustomClass());
    }
  }

  @Override
  public void encodeEndInternal(final FacesContext facesContext, final T component) throws IOException {

    if (!component.isPlain()) {
      final TobagoResponseWriter writer = getResponseWriter(facesContext);
      writer.endElement(HtmlElements.TOBAGO_FORM);
    }
  }
}
